==> wolframalpha_0.1.2.tar.gz: wolframalpha-0.1.2/main.cpp <==
#include "qmlapplicationviewer.h"
#include <QtGui/QApplication>
#include <QDeclarativeContext>
#include <QtDeclarative>

int main ( int argc, char *argv[] )
{
        QApplication app(argc, argv);


        QmlApplicationViewer viewer;
        viewer.setAttribute(Qt::WA_NoSystemBackground);

        QDeclarativeContext *context = viewer.rootContext();
        //view.engine()->addImportPath("/opt/qtm11/imports");
        viewer.engine()->addImportPath("/opt/qtm11/imports");

#ifdef Q_OS_SYMBIAN
        viewer.setSource(QUrl::fromLocalFile("e:/qml/wfa.qml"));
#else
        viewer.setMainQmlFile(QLatin1String("/opt/wolframalpha/qml/wolframalpha/wfa.qml"));
#endif

	viewer.rootContext()->setContextProperty("theapi", "RQ9RG9-8Y5A826VT5");
        viewer.showFullScreen();


        return app.exec();

}


/*
//#include "wfarequests.h"
#include <QtGui/QApplication>
#include <QDeclarativeView>
#include <QDeclarativeContext>
#include <QDeclarativeEngine>
#include <QDeclarativeNetworkAccessManagerFactory>
#include <QtNetwork/QNetworkAccessManager>
#include <QtNetwork/QNetworkConfiguration>
#include <QDebug>

class MyNetworkAccessManagerFactory : public QDeclarativeNetworkAccessManagerFactory
{
public:
    virtual QNetworkAccessManager *create(QObject *parent);
};

QNetworkAccessManager *MyNetworkAccessManagerFactory::create(QObject *parent = 0)
{
    QNetworkAccessManager *nam = new QNetworkAccessManager(parent);

    //nam->setCookieJar(jar);
    return nam;
}


int main(int argc, char *argv[])
{
    QApplication a(argc, argv);

    //qRegisterMetaType<MyClass>("MyClass");
//    qmlRegisterType<WfaRequests>("WfaRequests", 1, 0, "WfaRequests");

//    qmlRegisterType<OauthStuff>("OauthStuff", 1, 0, "OauthStuff");
//    qmlRegisterType<NetworkStuff>("NetworkStuff",1,0, "NetworkStuff");

    QDeclarativeView view;
    //view->engine()->addImportPath(settings.value("Dir",
    /*
MyNetworkAccessManagerFactory *factory = new MyNetworkAccessManagerFactory;
        QNetworkAccessManager *manager = factory->create();
        viewer.engine()->setNetworkAccessManagerFactory(factory);

*/
/*
    MyNetworkAccessManagerFactory *factory = new MyNetworkAccessManagerFactory;
    QNetworkAccessManager *manager = factory->create();


    view.engine()->setNetworkAccessManagerFactory(factory);
    //qRegisterMetaType
    //context->setContextProperty("Class1", new Class1);;
/*
    qRegisterMetaType<QNetworkConfigurationPrivatePointer>("QNetworkConfigurationPrivatePointer");*/
    //view.engine()->addImportPath("/opt/qtm11/imports");
    //view.rootContext()->setContextProperty("urlvalue", ""+oauthstuff.getToken());
                                           //"https://www.linkedin.com/uas/oauth/authorize?oauth_token="+tk);
    //view.setSource(QUrl::fromLocalFile("wfa.qml"));
    // view.rootContext()->setContextProperty("currentDateTime", QDateTime::currentDateTime());
    //view.rootContext()->setContextProperty("theapi", "RQ9RG9-8Y5A826VT5");
    //view.rootContext()->setContextProperty("QNetworkConfigurationPrivatePointer", new QNetworkConfigurationPrivatePointer);
/*
    view.showFullScreen();

    return a.exec();
}
*/

==> wolframalpha_0.2.1.tar.gz: wolframalpha-0.2.1/main.cpp <==
#include "qmlapplicationviewer.h"
#include <QtGui/QApplication>
#include <QDeclarativeContext>
#include <QtDeclarative>

int main ( int argc, char *argv[] )
{
        QApplication app(argc, argv);
//        const char[] apikey; // set this one to your own api key

        QmlApplicationViewer viewer;
        viewer.setAttribute(Qt::WA_NoSystemBackground);

        QDeclarativeContext *context = viewer.rootContext();
        //view.engine()->addImportPath("/opt/qtm11/imports");
        viewer.engine()->addImportPath("/opt/qtm11/imports");

#ifdef Q_OS_SYMBIAN
        viewer.setSource(QUrl::fromLocalFile("e:/qml/wfa.qml"));
#else
        viewer.setMainQmlFile(QLatin1String("/opt/wolframalpha/qml/wolframalpha/wfa.qml"));
#endif
        //getting api key from file

        QString apikey;
        QFile apifile("/home/user/.wolframalpha/apikey.txt");
        apifile.open(QFile::ReadOnly);
        apikey = apifile.readAll();
		apikey = apikey.trimmed();
        apifile.close();

        /*char apikey[20];
        std::ifstream apifile("/home/user/.wolframalpha/apikey.txt");
        apifile >> apikey;*/

        //setting it
        viewer.rootContext()->setContextProperty("theapi", apikey);
        viewer.showFullScreen();


        return app.exec();

}


/*
//#include "wfarequests.h"
#include <QtGui/QApplication>
#include <QDeclarativeView>
#include <QDeclarativeContext>
#include <QDeclarativeEngine>
#include <QDeclarativeNetworkAccessManagerFactory>
#include <QtNetwork/QNetworkAccessManager>
#include <QtNetwork/QNetworkConfiguration>
#include <QDebug>

class MyNetworkAccessManagerFactory : public QDeclarativeNetworkAccessManagerFactory
{
public:
    virtual QNetworkAccessManager *create(QObject *parent);
};

QNetworkAccessManager *MyNetworkAccessManagerFactory::create(QObject *parent = 0)
{
    QNetworkAccessManager *nam = new QNetworkAccessManager(parent);

    //nam->setCookieJar(jar);
    return nam;
}


int main(int argc, char *argv[])
{
    QApplication a(argc, argv);

    //qRegisterMetaType<MyClass>("MyClass");
//    qmlRegisterType<WfaRequests>("WfaRequests", 1, 0, "WfaRequests");

//    qmlRegisterType<OauthStuff>("OauthStuff", 1, 0, "OauthStuff");
//    qmlRegisterType<NetworkStuff>("NetworkStuff",1,0, "NetworkStuff");

    QDeclarativeView view;
    //view->engine()->addImportPath(settings.value("Dir",
    /*
MyNetworkAccessManagerFactory *factory = new MyNetworkAccessManagerFactory;
        QNetworkAccessManager *manager = factory->create();
        viewer.engine()->setNetworkAccessManagerFactory(factory);

*/
/*
    MyNetworkAccessManagerFactory *factory = new MyNetworkAccessManagerFactory;
    QNetworkAccessManager *manager = factory->create();


    view.engine()->setNetworkAccessManagerFactory(factory);
    //qRegisterMetaType
    //context->setContextProperty("Class1", new Class1);;
/*
    qRegisterMetaType<QNetworkConfigurationPrivatePointer>("QNetworkConfigurationPrivatePointer");*/
    //view.engine()->addImportPath("/opt/qtm11/imports");
    //view.rootContext()->setContextProperty("urlvalue", ""+oauthstuff.getToken());
                                           //"https://www.linkedin.com/uas/oauth/authorize?oauth_token="+tk);
    //view.setSource(QUrl::fromLocalFile("wfa.qml"));
    // view.rootContext()->setContextProperty("currentDateTime", QDateTime::currentDateTime());
    //view.rootContext()->setContextProperty("theapi", "RQ9RG9-8Y5A826VT5");
    //view.rootContext()->setContextProperty("QNetworkConfigurationPrivatePointer", new QNetworkConfigurationPrivatePointer);
/*
    view.showFullScreen();

    return a.exec();
}
*/
